Platform abstraction for types that differ between native and WASM.
On native targets, re-exports from std::time.
On wasm32, re-exports from web_time which uses js_sys::Date under the hood.
Structs
- Instant
- A measurement of a monotonically nondecreasing clock.
Opaque and useful only with
Duration. - System
Time - A measurement of the system clock, useful for talking to external entities like the file system or other processes.
Constants
- UNIX_
EPOCH - An anchor in time which can be used to create new
SystemTimeinstances or learn about where in time aSystemTimelies.